@@ -20,7 +20,7 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: search.c,v 1.49 2005/07/11 06:10:26 rrt Exp $	*/
+/*	$Id: search.c,v 1.50 2005/08/06 16:23:30 rrt Exp $	*/
 
 #include "config.h"
 
@@ -412,7 +412,7 @@ static int isearch(int dir, int regexp)
         thisflag |= FLAG_NEED_RESYNC;
       } else
         ding();
-    } else if (c & KBD_CTL && ((c & 0xff) == 'r' || (c & 0xff) == 's')) {
+    } else if (c & KBD_CTRL && ((c & 0xff) == 'r' || (c & 0xff) == 's')) {
       /* Invert direction. */
       if ((c & 0xff) == 'r' && dir == ISEARCH_FORWARD)
         dir = ISEARCH_BACKWARD;
@@ -428,7 +428,7 @@ static int isearch(int dir, int regexp)
       }
       else if (last_search != NULL)
         astr_cpy_cstr(pattern, last_search);
-    } else if (c & KBD_META || c & KBD_CTL || c > KBD_TAB) {
+    } else if (c & KBD_META || c & KBD_CTRL || c > KBD_TAB) {
       if (c == KBD_RET && astr_len(pattern) == 0) {
         if (dir == ISEARCH_FORWARD) {
           if (regexp)
