@@ -1,4 +1,4 @@
-/*	$Id: tbl_vars.h,v 1.17 2004/11/14 21:57:54 rrt Exp $	*/
+/*	$Id: tbl_vars.h,v 1.22 2005/02/14 21:57:48 rrt Exp $	*/
 
 /*
  * Add an entry to this list for declaring a new global variable.
@@ -19,7 +19,9 @@ Remap the help functions (bound by default to `C-h') to `M-h'.  This may\n\
 be useful when `C-h' is already bound to Backspace or Delete.\n\
 \n\
 Please note that changing this variable at run-time has no effect; you\n\
-need instead to modify your `~/.zilerc' configuration file and restart Zile.")
+need instead to modify your `~/.zile' configuration file and restart Zile.")
+X("auto-fill-mode",			"b", "false", "\
+If enabled, the Auto Fill Mode is automatically enabled.")
 X("backup-directory",			"", "~/.backup", "\
 Specify target backup directory.  Directory must be existent.\n\
 This value is used only when the `backup-with-directory' value is true.")
@@ -38,21 +40,25 @@ the directory must exist and must be specified in the\n\
 variable `backup-directory'.")
 X("beep",				"b", "true", "\
 If enabled, a sound will be emitted on any error.")
+X("case-replace",			"b", "true", "\
+Non-nil means `query-replace' should preserve case in replacements.")
 X("expand-tabs",			"b", "false", "\
 If disabled, Zile will insert hard tabs (the character `\\t'),\n\
 otherwise it will insert spaces.")
 X("fill-column",			"", "72", "\
-The default fill column (used in Auto Fill Mode).")
+Column beyond which automatic line-wrapping should happen.\n\
+Automatically becomes buffer-local when set in any fashion.")
 X("highlight-nonselected-windows",	"b", "false", "\
 If enabled, highlight region even in nonselected windows.")
+X("kill-whole-line",			"b", "false", "\
+If enabled, `kill-line' with no arg at beg of line kills the whole line.")
 X("skip-splash-screen",			"b", "false", "\
 If enabled, the splash screen at startup will be avoided.")
 X("standard-indent",			"", "4", "\
 Default number of columns for margin-changing functions to indent.")
 X("tab-width",				"", "8", "\
-The default tabulation width.")
-X("auto-fill-mode",			"b", "false", "\
-If enabled, the Auto Fill Mode is automatically enabled.")
+Distance between tab stops (for display of tab characters), in columns.\n\
+Automatically becomes buffer-local when set in any fashion.")
 X("transient-mark-mode",		"b", "true", "\
 If enabled, deactivates the mark when the buffer contents change.\n\
 Also enables highlighting of the region whenever the mark is active.\n\
